<?php
/**
 * Admin Class
 *
 * @package SurvForm
 * @since   1.0.0
 */

class Surv_Admin{

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'admin_enqueue_scripts', 	array( $this, 'admin_scripts' ), 10 );
		add_action( 'admin_menu', 				array($this, 'register_menu' ) );
		add_action( 'admin_init', 				array($this, 'register_options') );
	}

	/**
	 * Creates the dashboard page
	 * @see  add_theme_page()
	 * @since 1.0.0
	 */
	public function register_menu() {
		add_menu_page( 'SurvForm', 'SurvForm', 'edit_theme_options', 'survform', array( $this, 'admin_page' ), '' );
		add_submenu_page( 'survform', 'Surv Settings', 'Settings', 'edit_theme_options', 'survform', array( $this, 'admin_page' ) );

		$admin_submenu = array();

	 	$admin_submenu['survform'] = array(
	 		'menu_name'  => esc_html__('Survey Data', 'survform'),
	 		'page_title' => esc_html__('Survey Data', 'survform'),
	 		'menu_page'  => null,
	 		'slug'		 => 'edit.php?post_type=surv-data',
	 		'capability' => 'edit_posts'
	 	);

	 	foreach( $admin_submenu as $key => $value ) {
		  add_submenu_page( 'survform', $value['page_title'], $value['menu_name'], $value['capability'], $value['slug'], $value['menu_page'] );
		}
	}

	public function admin_page(){
		require_once SURV_ABSPATH . 'includes/admin-page.php';
	}

	/**
	 * Register Option Setting
	 * @since 1.0.0
	 */
	public function register_options() {
	   $options = SurvForm()->options;

	   foreach( $options as $key => $val ) {
	   	  add_option( $key, $val );
	      register_setting( 'surv_option_group', $key, $val );
	   }
	}

    /**
     * Load Admin Style & Scripts
     */
    public function admin_scripts() {
    	wp_enqueue_style( 'surv-design-admin-style', plugins_url( 'assets/css/admin.css', SURV_FILE ) );
    	wp_enqueue_script( 'surv-design-admin-script', plugins_url( 'assets/js/admin.js', SURV_FILE ), array( 'jquery', 'imagesloaded', 'masonry' ), '', true );
    }

    /**
     * Text Field
     */
	public static function text( $name, $val, $readonly, $visible ) {

	  if( null !== get_option( $name ) && get_option( $name ) !== '' ){
	  	 $val = get_option( $name );
	  }

	  $readonly_prop = $readonly ? 'readonly' : '';
	  $type = $visible ? 'text' : 'password';

	  $return_html = '<input name="' . $name . '" type="' . $type . '" class="surv-textfield" value="' . esc_attr( $val ) . '" ' . $readonly_prop . '>';      
      echo $return_html;
	}

	/**
     * Email Field
     */
	public static function email( $name, $val, $readonly ) {

	  if( null !== get_option( $name ) && get_option( $name ) !== '' ){
	  	 $val = get_option( $name );
	  }

	  $readonly_prop = $readonly ? 'readonly' : '';

	  $return_html = '<input name="' . $name . '" type="email" class="surv-textfield" value="' . $val . '" ' . $readonly_prop . '>';
      echo $return_html;
	}

	/**
     * Hidden Field
     */
	public static function hidden( $name, $val ) {
	  if(null !== get_option($name) && get_option($name)<>''){
	  	 $val = get_option($name);
	  }
	  $return_html = '<input name="'.$name.'" type="hidden" class="surv-textfield" value="'.$val.'">';
      echo $return_html;
	}

	/**
     * Checkbox Field
     */
	public static function checkbox( $name, $val ) {
	  if( null !== get_option( $name ) && get_option( $name ) !== '' ) {
	  	 $val = get_option( $name );
	  }

	  $checked = $val ? 'checked="checked"' : '';

	  $return_html = '<input name="' . $name . '" type="checkbox" value="1" ' . $checked . '>';

      echo $return_html;
	}
}

return new Surv_Admin();
