<?php
/**
 * SurvForm Class
 *
 * @package SurvForm
 * @since   1.0.7.8
 */

defined( 'ABSPATH' ) || exit;

/**
 * Main SurvForm Class.
 *
 * @class SurvForm
 */
final class SurvForm {

	/**
	 * Version.
	 *
	 * @var string
	 */
	public $version = '1.0.7.9';

	/**
	 * The single instance of the class.
	 *
	 * @var SurvForm
	 * @since 1.0.0
	 */
	protected static $_instance = null;

	/**
	 * SurvForm Post Type.
	 *
	 * @var string
	 */
	private $surv_instance;

	/**
	 * Quiz Templates Instance.
	 *
	 * @var surv_templates
	 */
	private $surv_templates;

	/**
	 * Options
	 *
	 * @var options
	 */
	public $options = array(
		  'surv_send_mail' => 0,
		  'surv_receiver_email' => '',
			'surv_final_redirect_url' => '/',
			'surv_final_back_text' => 'Back to home',
			'surv_text_enter_text' => 'Please answer the question before you go to the next.',
   	  'surv_text_enter_email' => 'Please enter a email address.',
   	  'surv_text_enter_valid_email' => 'Please enter a valid email address.',
   	  'surv_text_enter_password' => 'Please enter the password.',
   	  'surv_text_enter_strong_password' => 'Please set a stronger password which must contains at least one uppercase letter and number, minimal 8 characters.',
   	  'surv_text_enter_url' => 'Please enter a URL.',
   	  'surv_text_enter_valid_url' => 'Please enter a valid URL.',
   	  'surv_text_enter_username' => 'Please enter your username.',
   	  'surv_text_almost_have_done_title' => 'Almost have done, please log in or create an account.',
   	  'surv_text_login_username_placeholder' => 'Username or Email',
   	  'surv_text_login_password_placeholder' => 'Password',
   	  'surv_text_register_email_placeholder' => 'Email Address',
   	  'surv_text_login_form_title' => 'Login',
   	  'surv_text_register_form_title' => 'Sign Up',
   	  'surv_text_login_button_text' => 'Log In',
   	  'surv_text_register_button_text' => 'Create An Account',
   	  'surv_text_login_link_text' => 'Already a member? Log in',
   	  'surv_text_register_link_text' => 'Create an account',
   	  'surv_text_submit_screen_title' => 'Great! Please submit your choices, thanks for your patience!',
   	  'surv_text_submit_button_text' => 'Submit',
   	  'surv_text_success_screen_title' => 'Success! Thank You!',
   	  'surv_text_exceed_max_choices' => 'You can only select %s choices!',
	);

	/**
	 * Main SurvForm Instance.
	 *
	 * Ensures only one instance of SurvForm is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @static
	 * @see SurvForm()
	 * @return SurvForm - Main instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Cloning is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __clone() {
		wc_doing_it_wrong( __FUNCTION__, esc_html__( 'Cloning is forbidden.', 'survform' ), $this->version );
	}

	/**
	 * Unserializing instances of this class is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __wakeup() {
		wc_doing_it_wrong( __FUNCTION__, esc_html__( 'Unserializing instances of this class is forbidden.', 'survform' ), $this->version );
	}

	/**
	 * Surv_Design Constructor.
	 */
	public function __construct() {
		$this->define_constants();
		$this->includes();
		$this->init_hooks();
		$this->instances();
	}

	/**
	 * Init Hooks
	 */
	public function init_hooks(){
		add_action( 'init', array($this,'textdomain') );
		add_action( 'activated_plugin', array( $this, 'activation' ) );
    add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ), 10 );
    add_action( 'init', array( $this, 'auto_update' ) );
	}

	/**
	 * Define Constants.
	 */
	private function define_constants() {
		$this->define( 'SURV_DEBUG', false );
		$this->define( 'SURV_ABSPATH', dirname( SURV_FILE ) . '/' );
		$this->define( 'SURV_PLUGIN_BASENAME', plugin_basename( SURV_FILE ) );
		$this->define( 'SURV_DIR', plugin_dir_path( dirname( __FILE__ ) ) );
    $this->define( 'SURV_ROOT_DIR', plugins_url() . '/' . plugin_basename( SURV_DIR ) . '/' );
		$this->define( 'SURV_VERSION', $this->version );
	}

	/**
	 * Define constant if not already set.
	 *
	 * @param string      $name  Constant name.
	 * @param string|bool $value Constant value.
	 */
	private function define( $name, $value ) {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	public function activation(){
	   foreach( $this->options as $key => $val ) {
	   	  if( get_option( $key ) !== '' || get_option( $key ) !== NULL ) {
	   		  update_option( $key, $val );
	   	  } else {
	   	  	  add_option( $key, $val );
	   	  }
	   }
	}

	/**
     * Localize
     */
	public function textdomain() {
	   load_plugin_textdomain( 'survform', FALSE, dirname( plugin_basename( SURV_FILE ) ) . '/languages/' );
	}

    /**
     * Load Style & Scripts
     * @version: 1.0.3
     */
    public function scripts() {
    	if( ! is_page_template( 'surv-form-page-template' ) ) {
    		return;
    	}
    	wp_enqueue_style( 'surv-style', plugins_url( 'assets/css/survform.css', SURV_FILE ), array(), $this->version );
    	wp_enqueue_style( 'surv-theme-style', plugins_url( 'assets/css/themes/default.css', SURV_FILE ) );
    	wp_enqueue_script( 'surv-script', plugins_url( 'assets/js/survform.js', SURV_FILE ), array( 'jquery', 'masonry', 'imagesloaded' ), $this->version, true );
    	wp_enqueue_script( 'wp-api' );
    	wp_localize_script( 'wp-api', 'wpApiSettings', array(
		    'root' => esc_url_raw( rest_url() ),
		    'nonce' => wp_create_nonce( 'wp_rest' )
		) );
    	wp_localize_script( 'surv-script', 'surv_data',
    		array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) )
    	);
    	wp_localize_script( 'surv-script', 'surv_text',
    		array(
					'enterText' => esc_html( get_option( 'surv_text_enter_text' ) ),
    			'enterEmail' => esc_html( get_option( 'surv_text_enter_email' ) ),
    			'enterValidEmail' => esc_html( get_option( 'surv_text_enter_valid_email' ) ),
    			'enterPassword' => esc_html( get_option( 'surv_text_enter_password' ) ),
    			'enterStrongPassword' => esc_html( get_option( 'surv_text_enter_strong_password' ) ),
    			'enterURL'	=> esc_html( get_option( 'surv_text_enter_url' ) ),
    			'enterValidURL' => esc_html( get_option( 'surv_text_enter_valid_url' ) ),
    			'enterUsername' => esc_html( get_option( 'surv_text_enter_username' ) ),
    			'doneText' => get_option( 'surv_text_success_screen_title' ),
    			'exceedMaxChoicesText' => get_option( 'surv_text_exceed_max_choices' )
    		)
    	);
    }

	/**
	 * Include required core files used in admin and on the frontend.
	 */
	public function includes() {
		include_once SURV_ABSPATH . 'includes/class-page-template.php';
		include_once SURV_ABSPATH . 'includes/class-form-page-template.php';
		include_once SURV_ABSPATH . 'includes/class-post-type.php';
		include_once SURV_ABSPATH . 'includes/class-survey-data.php';
		include_once SURV_ABSPATH . 'includes/class-admin.php';
		include_once SURV_ABSPATH . 'includes/functions.php';
		include_once SURV_ABSPATH . 'includes/options/init.php';
		include_once SURV_ABSPATH . 'includes/settings.php';
		include_once SURV_ABSPATH . 'includes/ajax-sign-up-in.php';
	}

	public function auto_update(){

		require_once SURV_ABSPATH . "includes/plugin-update-checker/plugin-update-checker.php";
		$SF_UpdateChecker = Puc_v4_Factory::buildUpdateChecker(
			'https://focuxtheme.com/update-server/?action=get_metadata&slug=survform',
			SURV_FILE,
			'survform'
		);

	}

	/**
	 * Setup Instances
	 */
	public function instances() {
		$this->surv_instance = new Surv_Data();
		$this->surv_templates = new Surv_Page_Templates();
	}

}
