<?php
/**
 * Plugin Page Templates Loader
 *
 * @package SurvForm
 * @since   1.0.0
 */

defined( 'ABSPATH' ) || exit;

if( ! class_exists('Surv_Plugin_Page_Templates_Loader') ){

	/**
	 * Main Surv_Plugin_Page_Templates_Loader Class.
	 */
	class Surv_Plugin_Page_Templates_Loader {

		/**
		 * Page Template Value Prefix
		 * @since 1.0.0
		 */
		public $prefix = 'surv-';

		/**
		 * Page Template List
		 * @since 1.0.0
		 */
		public $page_templates = array();

		/**
		 * Page Template Folder Path
		 * @since 1.0.0
		 */
		public $page_template_dir = '';

		/**
		 * Page Template Folder Path in Theme Folder
		 * @since 1.0.0
		 */
		public $page_template_theme_dir = '';

		/**
		 * Constructor.
		 */
		public function __construct() {
			add_filter( 'theme_page_templates', array( $this, 'register_page_templates' ) );
			add_filter( 'template_include',     array( $this, 'load_page_template' ) );
		}

		/**
		 * Add plugin page template to the page attribute drop menu.
		 */
		public function register_page_templates( $page_template ){

			if( ! isset( $this->page_templates ) ){
				return;
			}

		    $page_template = array_merge( $page_template, $this->page_templates );
		    return $page_template;
		}

		/**
		 * Load page template from plugin
		 */
		public function load_page_template( $template ) {

			if( ! isset( $this->page_templates ) ){
				return;
			}

			foreach( $this->page_templates as $key => $value ){
				
				$key_strings = explode( $this->prefix, $key);
				$filename = $key_strings[1] . '.php';

			    if(  get_page_template_slug() === $key ) {

			        if ( $theme_file = locate_template( array( $this->page_template_theme_dir . $filename ) ) ) {
			            $template =  $theme_file;
			        } else {
			            $template = $this->page_template_dir . $filename;
			        }
			    }
		    }

		    if( $template == '' ) {
		        throw new \Exception('No template found');
		    }
		    return $template;
		}

	}
	
}