<?php
/**
 * Survey Data Class
 *
 * @package SurvForm
 * @since   1.0.0
 */

class Surv_Data{

	private $post_type = 'surv-data';
	private $post_type_slug = 'surv-data';

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->post_type();
		$this->actions();
	}

	public function actions(){
		add_action( "wp_ajax_update_surv_data", array( $this, "update_surv_data" ) );
		add_action( "wp_ajax_nopriv_update_surv_data", array( $this, "update_surv_data" ) );
		add_action( "wp_ajax_save_surv_data", array( $this, "save_surv_data" ) );
		add_action( "wp_ajax_nopriv_save_surv_data", array( $this, "save_surv_data" ) );
		add_action( 'add_meta_boxes', array( $this, 'create_metabox' ) );
		add_action( 'admin_head' , array( $this, 'remove_avada_metabox' ) );
		add_action( 'rest_api_init', array( $this, 'register_meta_api') );
	}

	public function post_type() {
		$surv_data = new Surv_PostType();
	    $surv_data->post_type = $this->post_type;
	    $surv_data->post_type_slug = $this->post_type_slug;
	    $surv_data->show_in_menu = false;
	    $surv_data->show_in_rest = true;

	    $surv_data->post_type_labels = array(
                    'name'               => _x( 'Survey Data', 'post type general name', 'survform' ),
                    'singular_name'      => _x( 'Survey Data', 'post type singular name', 'survform' ),
                    'menu_name'          => _x( 'Survey Data', 'admin menu', 'survform' ),
                    'name_admin_bar'     => _x( 'Survey Data', 'add new on admin bar', 'survform' ),
                    'add_new'            => _x( 'Add New', 'surv data', 'survform' ),
                    'add_new_item'       => __( 'Add New Survey Data', 'survform' ),
                    'new_item'           => __( 'New Survey Data', 'survform' ),
                    'edit_item'          => __( 'Edit Survey Data', 'survform' ),
                    'view_item'          => __( 'View Survey Data', 'survform' ),
                    'all_items'          => __( 'All Survey Data', 'survform' ),
                    'search_items'       => __( 'Search Survey Data', 'survform' ),
                    'parent_item_colon'  => __( 'Parent Survey Data:', 'survform' ),
                    'not_found'          => __( 'No Survey Data found.', 'survform' ),
                    'not_found_in_trash' => __( 'No Survey Data found in Trash.', 'survform' )
                  );
	    $surv_data->capabilities = array(
   			 'create_posts' => 'do_not_allow', // false < WP 4.5, credit @Ewout
	    );
	    $surv_data->map_meta_cap = true;
	}

	/**
	 * Add the meta fields to REST API responses for posts read and write
	 * Read and write a post meta fields in post responses
	 */
	public function register_meta_api() {
	    //Meta Fields that should be added to the API
	    $meta_fields = array(
	        'surv_data',
	        'surv_form_id'
	    );
	    //Iterate through all fields and add register each of them to the API
	    foreach ($meta_fields as $field) {
	        register_rest_field( $this->post_type,
	            $field,
	            array(
	                'get_callback'    => array( $this, 'get_meta'),
	                'update_callback' => array( $this, 'update_meta'),
	                'schema'          => null,
	            )
	        );
	    }
	}

	/**
	 * Handler for getting custom field data.
	 *
	 * @since 0.1.0
	 *
	 * @param array $object The object from the response
	 * @param string $field_name Name of field
	 *
	 * @return mixed
	 */
	public function get_meta( $object, $field_name ) {
	    return get_post_meta( $object[ 'id' ], $field_name );
	}

	/**
	 * Handler for updating custom field data.
	 *
	 * @since 0.1.0
	 * @link  http://manual.unyson.io/en/latest/helpers/php.html#database
	 * @param mixed $value The value of the field
	 * @param object $object The object from the response
	 * @param string $field_name Name of field
	 *
	 * @return bool|int
	 */
	public function update_meta( $value, $object, $field_name ) {
	    if ( ! $value || ! is_string( $value ) ) {
	        return;
	    }

	    return update_post_meta( $object->ID, $field_name, maybe_serialize( strip_tags( $value ) ) );
	}

	public function update_surv_data(){

		 if ( ! wp_verify_nonce( $_REQUEST['nonce'], "surv_form_nonce" ) ) {
	        exit( "No naughty business please" );
	     }

		 if( ! isset( $_REQUEST['post_id'] ) ) {
		 	return;
		 }

		 $status = $_REQUEST['post_status'] !== '' ? $_REQUEST['post_status'] : 'draft';

		 $post_args = array(
		      'ID'            => $_REQUEST['post_id'],
		      'post_status'   => $status,
		      'post_type'     => $this->post_type,
		      'post_author'   => $_REQUEST['user_id']
		 );

		 wp_update_post( $post_args );
		 update_post_meta( $_REQUEST['post_id'], 'surv_data', $_REQUEST['surv_data'] );

		 if( $status === 'publish' ) {
		 	$this->send_mail( array(
		 		'user_id' => $_REQUEST['user_id'],
		 		'surv_data' => $_REQUEST['surv_data'],
		 		'title' => $_REQUEST['title']
		 	) );
		 }

		 exit();
	}

	public function save_surv_data(){

		if ( ! wp_verify_nonce( $_REQUEST['nonce'], "surv_form_nonce" ) ) {
	       exit( "No naughty business please" );
	    }

		$user = get_user_by( 'id', $_REQUEST['user_id'] );
	    $tester = $_REQUEST['user_id'] > 0 ? $user->display_name : esc_html__( 'Visitor', 'survform' );
	    $status = $_REQUEST['post_status'] !== '' ? $_REQUEST['post_status'] : 'publish';


		$post_args = array(
		      'post_title'    => $_REQUEST['title'] . ' - ' . $tester,
		      'post_status'   => $status,
		      'post_type'     => $this->post_type,
		      'post_author'   => $_REQUEST['user_id'],
		      'post_content'  => ' ',
		      'meta_input'    => array(
		        'surv_data'   => $_REQUEST['surv_data'],
		      )
		);

		$post = wp_insert_post( $post_args, $wp_error );
		echo $post;

		if( $status === 'publish' ) {
		 	$this->send_mail( array(
		 		'user_id' => $_REQUEST['user_id'],
		 		'surv_data' => $_REQUEST['surv_data'],
		 		'title' => $_REQUEST['title']
		 	) );
		}

		exit();
	}

	public function send_mail( $args ) {
		if( get_option('surv_send_mail') !== '1' ) {
			return;
		}

		require_once(ABSPATH .'/wp-admin/includes/file.php');

		WP_Filesystem();
		global $wp_filesystem;

	 	$log_dir = WP_CONTENT_DIR . '/survform/';

    if ( ! is_dir( $log_dir ) ) {
	   wp_mkdir_p( $log_dir );
    }

		$receiver = get_option('surv_receiver_email') !== '' || get_option('surv_receiver_email') !== null ? get_option('surv_receiver_email') : '';

		if( $receiver === '' ) {
			return;
		}

		$tester = isset( $args['user_id'] ) ? get_userdata( $args['user_id'] ) : '';
		$tester_name = $test !== '' ? $tester->display_name : esc_html__( 'Anonymous', 'survform' );

      //Send Mail
      $subject = sprintf( esc_html__( 'Survey Result: %s', 'survform' ), $args['title'] );
      $sender = get_option('name');

      $data = json_decode(  stripslashes( $args['surv_data'] ), true );
      $message = '<div style="width: 500px; border: 2px solid #eee; padding: 30px;">
          <h1 style="font-size: 2em;">' . $args['title']  . '</h1>
          <ul style="margin-top: 40px; margin-left: 0; padding-left: 0; list-style: none;">
          <li style="border-bottom: 1px solid #ddd; padding-bottom: 15px; margin-bottom: 15px;"><strong style="margin-right: 15px;">' . esc_html__( 'Respondent', 'survform' ) . ': </strong> ' . $tester_name . '</li>';

   		foreach( $data as $item ) {
			if( strpos( $item['value'], '.jpg') || strpos( $item['value'], '.png') || strpos( $item['value'], '.gif') || strpos( $item['value'], '.jpeg') ) {
				$images = explode( '|', $item['value'] );
				$message .= '<li style="border-bottom: 1px solid #ddd; padding-bottom: 15px; margin-bottom: 15px;"><strong style="margin-right: 15px;">' . $item['question'] . ': </strong>
					<div style="margin-top: 15px; width: 600px;column-count: 3; column-gap: 0;">';
					foreach( $images as $image ){
						$message .= '<span style="width: 30%; break-inside: avoid; margin: 0 5px 5px 0; overflow: hidden; display: inline-block;"><a href=" ' . $image . ' " target="_blank"><img src="' . $image . '" style="width: 150px; height: auto;" /></a></span>';
					}
					$message .= '</div>
				</li>';
			}else{
				$message .= '<li style="border-bottom: 1px solid #ddd; padding-bottom: 15px; margin-bottom: 15px;"><strong style="margin-right: 15px;">' . $item['question'] . ': </strong>' . $item['value'] . '</li>';
			}
		}

    $message .= '
        </ul>
    </div>';

    $headers[] = 'Content-type: text/html; charset=UTF-8' . "\r\n";
    $headers[] = 'From: '. get_bloginfo('name') .' <' . get_option('admin_email') . '>' . "\r\n";
    $headers[] = 'Reply-To: '.$sender.' <' . get_option('admin_email') . '>' . "\r\n";

    $mail = wp_mail( $receiver, $subject, $message, $headers ); 

    if( ! $mail ) {
	    $wp_filesystem->put_contents(
			  $log_dir . 'mail.log',
			  $campaign . ' campaign result sent failed - ' . date('y-m-d H:i:s') . PHP_EOL,
			  FS_CHMOD_FILE
	  	);
    } else {
	    $wp_filesystem->put_contents(
			  $log_dir . 'mail.log',
			  $campaign . ' campaign result sent successfully - ' . date('y-m-d H:i:s') . PHP_EOL,
			  FS_CHMOD_FILE
		  );
    }
	}


	public function create_metabox(){
		add_meta_box(
	        'surv-data',
	        __( 'Survey Data', 'survform' ),
	        array( $this, 'surv_data_meta_box_callback' ),
	        $this->post_type,
	        'normal',
	        'high'
	    );
	}

	public function surv_data_meta_box_callback(){
		global $post;

		$user = get_user_by( 'id', $post->post_author );
		$data = json_decode( get_post_meta( $post->ID, 'surv_data', true ), true );

		echo '<ul class="surv-data-list">';
		echo '<li><strong>' . esc_html__( 'Survey Campaign:', 'survform' ) . '</strong>' . $post->post_title . '</li>';
		echo '<li><strong>' . esc_html__( 'The User:', 'survform' ) . '</strong><a href=" '. admin_url( 'user-edit.php?user_id=' . $user->ID ) .'" target="_blank" title=" ' . esc_html__( 'Edit User', 'survform' ) . ' ">' . $user->display_name . '</a></li>';

		foreach( $data as $item ) {
			if( strpos( $item['value'], '.jpg') || strpos( $item['value'], '.png') || strpos( $item['value'], '.gif') || strpos( $item['value'], '.jpeg') ) {
				$images = explode( '|', $item['value'] );
				echo '<li class="surv-images-container"><strong class="wrap">' . $item['question'] . '</strong><div class="surv-images-data">';
				foreach( $images as $image ){
				  echo '<span class="item"><img src="'.$image.'" /></span>';
				}
				echo '</div></li>';
			}else{
				echo '<li><strong class="wrap">' . $item['question'] . '</strong>' . $item['value'] . '</li>';
			}
		}

		echo '</ul>';
	}

	/**
	 * Remove Custom Fields meta box
	 */
	public function remove_avada_metabox() {
	    remove_meta_box( 'pyre_post_options' , $this->post_type , 'advanced' );
	}

}
