<?php
/**
 * Plugin Functions
 *
 * @package SurvForm
 * @since   1.0.0
 */

/**
 * Generate Random String
 * @param the length of string(number), the max length limit of the string(number)
 * @return strings
 */
if( ! function_exists( 'surv_random' ) ) {
    function surv_random( $length, $max = FALSE ){
        if( is_int( $max ) && $max > $length ) {
            $length = mt_rand( $length, $max );
        }

        $output = '';

        for( $i = 0; $i < $length; $i++ ) {
            $which = mt_rand( 0, 2 );

            if( $which === 0 ) {
                $output .= mt_rand( 0, 9 );
            }elseif ( $which === 1 ){
                $output .= chr( mt_rand( 65,90 ) );
            }else{
                $output .= chr( mt_rand( 97, 122 ) );
            }
        }

        return $output;
    }
}

function surv_fuzzy( $str ) {
    return '"' . $str . '"';
}

/**
 * Get the image file name from the image URL
 * @param the image URL
 * @return the image file name
 */
if( ! function_exists( 'surv_get_image_name' ) ) {
    function surv_get_image_name( $url ){
        if ( strpos( $url, '?' ) !== false ) {
            $t = explode( '?', $url );
            $url = $t[0];
        }
        $pathinfo = pathinfo( $url );
        return $pathinfo['filename'];
    }
}

/**
 * Output the fields depends on the field types
 * @param the arguments of the field (array): id, label, placeholder, image_style, image_value_type, pin_boards, options
 * @return the field output
 */
if( ! function_exists( 'surv_fields' ) ) {
    function surv_fields( $args ){

        if( !isset( $args ) ) {
            return;
        }

        $prefix =   '_surv_';
        $field = '';
        $actual_link = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
        $step_link = strpos( $actual_link, '?' ) !== false ? $actual_link . '&' : $actual_link . '?';

        $label = isset( $args['label'] ) ? $args['label'] : '';
        $placeholder = isset( $args['placeholder'] ) ? $args['placeholder'] : '';
        $id  = isset( $args['id'] ) && $args['id'] !== '' ? $args['id'] : $prefix . surv_random( 8 );
        $image_value_type = isset( $args['image_value_type'] ) ? $args['image_value_type'] : 'url';
        $image_style = isset( $args['image_style'] ) ? $args['image_style'] : 'normal';
        $inline = isset( $args['inline'] ) &&  $args['inline'] !== '' ? 'surv-inline-fields' : '';

        switch( $args['field_type'] ) {
            case 'text':
                $field .= '<label for="' . esc_html( $id ) . '">
                            <span class="label-text">' . esc_html( $label ) . '</span>
                            <input type="text" id="' . esc_html( $id ) . '" name="' . esc_html( $id ) . '" placeholder="' . esc_html( $placeholder ) . '" />
                          </label>';
                break;

            case 'email':
                $field .= '<label for="' . esc_html( $id ) . '">
                            <span class="label-text">' . esc_html( $label ) . '</span>
                            <input type="email" id="' . esc_html( $id ) . '" name="' . esc_html( $id ) . '" placeholder="' . esc_html( $placeholder ) . '" />
                          </label>';
                break;

            case 'url':
                $field .= '<label for="' . esc_html( $id ) . '">
                            <span class="label-text">' . esc_html( $label ) . '</span>
                            <input type="url" id="' . esc_html( $id ) . '" name="' . esc_html( $id ) . '" placeholder="' . esc_html( $placeholder ) . '" />
                          </label>';
                break;

            case 'number':
                $field .= '<label for="' . esc_html( $id ) . '">
                            <span class="label-text">' . esc_html( $label ) . '</span>
                            <input type="number" id="' . esc_html( $id ) . '" name="' . esc_html( $id ) . '" placeholder="' . esc_html( $placeholder ) . '" />
                          </label>';
                break;

            case 'password':
                $field .= '<label for="' . esc_html( $id ) . '">
                            <span class="label-text">' .esc_html( $label ) . '</span>
                            <input type="password" id="' . esc_html( $id ) . '" name="' . esc_html( $id ) . '" placeholder="' . esc_html( $placeholder ) . '" />
                          </label>';
                break;

            case 'textarea':
                $field .= '<label for="' . esc_html( $id ) . '">
                            <span class="label-text">' . esc_html( $label ) . '</span>
                            <textarea type="text" id="' . esc_html( $id ) . '" name="' . esc_html( $id ) . '" placeholder="' . esc_html( $placeholder ) . '"></textarea>
                          </label>';
                break;

            case 'checkbox':
                $field .= '<label><span class="label-text">' . esc_html( $label ) . '</span></label>';

                $options  =  preg_split( "/((\r?\n)|(\r\n?))/", wp_strip_all_tags( $args['options'] ) );

                foreach( $options as $key => $value ) {
                    $field .= '<label class="surv-custom-checkbox-radio '. $inline .'">
                                    <span class="option-label">' . $value . '</span>
                                    <input type="checkbox" name="' . esc_html( $id ) . '[]" id="' . esc_html( $id ) . '['.$key.']" value="' . esc_html( $value ) . '" />
                                    <span class="surv-checkmark"></span>
                               </label>';

                }

                break;

            case 'radio':
                $field .= '<label><span class="label-text">' . esc_html( $label ) . '</span></label>';

                $options  =  preg_split( "/((\r?\n)|(\r\n?))/", wp_strip_all_tags( $args['options'] ) );

                foreach( $options as $key => $value ) {
                    $field .= '<label class="surv-custom-checkbox-radio '. $inline .'">
                                    <span class="option-label">' . $value . '</span>
                                    <input type="radio" name="' . esc_html( $id ) . '[]" id="' . esc_html( $id ) . '['.$key.']" value="' . esc_html( $value ) . '" />
                                    <span class="surv-checkmark surv-checkmark-radio"></span>
                               </label>';

                }

                break;

            case 'select':
                $field .= '<label for="' . esc_html( $id ) . '">
                <span class="label-text">' . esc_html( $label ) . '</span>';
                $options  =  preg_split( "/((\r?\n)|(\r\n?))/", wp_strip_all_tags( esc_html( $args['options'] ) ) );

                $field .= '<select id="' . esc_html( $id ) . '" name="'. esc_html( $id ) .'">';
                foreach( $options as $key => $value ) {
                    $field .= '<option value="' . esc_html( $value ) . '"> '. esc_html( $value ) .' </option>';
                }
                $field .= '</select>';

                $field .= '</label>';
                break;

            case 'checkbox-image':
                if ( isset( $args['images'] ) ) {
                    $image_data = $args['images'];

                    $count = count( $image_data );
                    $current_page = isset( $_GET['image_page'] ) ? $_GET['image_page'] : 1;
                    $per_page = 6;
                    $total_pages = ceil( $count / $per_page );
                    $images = array_slice( $image_data, ( $current_page-1 ) * $per_page, $per_page );
                    $image_value = '';
                    $icon_title = '';

                    $field .= '<div class="surv-image-picker">';

                    foreach( $images as $image ) {

                        switch( $image_value_type ){
                            case 'url':
                              $image_value = esc_url( $image );
                              break;
                            case 'title':
                              $image_value = esc_html( get_the_title( attachment_url_to_postid( $image ) ) );
                              break;
                            case 'id':
                              $image_value = esc_html( attachment_url_to_postid( $image ) );
                              break;
                        }

                        if( $image_style == 'icon' ) {
                            $icon_title = '<span>'.esc_html( get_the_title( attachment_url_to_postid( $image ) ) ).'</span>';
                        }

                        $field .= '<div class="image-item">
                            <input type="checkbox" id="' . $id . '[' . surv_get_image_name( $image ) . ']' .'" name="' . $id . '[]' . '" value=" ' . $image_value . ' " />
                            <label for="' . $id . '[' . surv_get_image_name( $image ) . ']' . '"><img src="' . esc_url( $image ) . '" loading="lazy" />'. $icon_title .'</label>
                        </div>';
                    }

                    $field .= '</div>

                    <div class="page-load-status">
                          <div class="infinite-scroll-request">
                                <div class="surv-ellipsis"><div></div><div></div><div></div><div></div></div>
                          </div>
                    </div>

                    <div class="surv-page-links">';

                    if( ! isset($_GET['image_page']) || $_GET['image_page'] <= 1 ) {
                        $field .= '';
                    }else{
                        $field .= '<a href="'. $step_link .'image_page=' . ( $current_page-1 ) . '" class="surv-previous-link">Previous</a>';
                    }

                    if( isset( $_GET['image_page'] ) && $_GET['image_page'] >= $total_pages ) {
                        $field .= '';
                    }else{
                        $field .= '<a href="'. $step_link .'image_page=' . ( $current_page+1 ) .'" class="surv-next-link">Next</a>';
                    }

                    $field .= '</div>';
                }else{
                    $field .= esc_html__( 'No image uploaded', 'survform' );
                }
                break;

            case 'radio-image':
                if ( isset( $args['images'] ) ) {
                    $image_data = $args['images'];

                    $count = count( $image_data );
                    $current_page = isset( $_GET['image_page'] ) ? $_GET['image_page'] : 1;
                    $per_page = 6;
                    $total_pages = ceil( $count / $per_page );
                    $images = array_slice( $image_data, ( $current_page-1 ) * $per_page, $per_page );
                    $image_value = '';

                    $field .= '<div class="surv-image-picker">';

                    foreach( $images as $image ) {

                        switch( $image_value_type ){
                            case 'url':
                              $image_value = esc_url( $image );
                              break;
                            case 'title':
                              $image_value = esc_html( get_the_title( attachment_url_to_postid( $image ) ) );
                              break;
                            case 'id':
                              $image_value = esc_html( attachment_url_to_postid( $image ) );
                              break;
                        }

                        if( $image_style == 'icon' ) {
                            $icon_title = '<span>'.esc_html( get_the_title( attachment_url_to_postid( $image ) ) ).'</span>';
                        }

                        $field .= '<div class="image-item">
                            <input type="radio" id="' . $id . '[' . surv_get_image_name( $image ) . ']' .'" name="' . $id . '" value=" ' . $image_value . ' " />
                            <label for="' . $id . '[' . surv_get_image_name( $image ) . ']' . '"><img src="' . esc_url( $image ) . '" loading="lazy" />' . $icon_title . '</label>
                        </div>';
                    }

                    $field .= '</div>

                    <div class="page-load-status">
                          <p class="infinite-scroll-request"><div class="lds-ellipsis"><div></div><div></div><div></div><div></div></div></p>
                    </div>

                    <div class="surv-page-links">';
                    if( ! isset($_GET['image_page']) || $_GET['image_page'] <= 1 ) {
                        $field .= '';
                    }else{
                        $field .= '<a href="' . $step_link . 'image_page=' . ( $current_page-1 ) . '" class="surv-previous-link">Previous</a>';
                    }

                    if( isset( $_GET['image_page'] ) && $_GET['image_page'] >= $total_pages ) {
                        $field .= '';
                    }else{
                        $field .= '<a href="' . $step_link . 'image_page=' . ( $current_page+1 ) .'" class="surv-next-link">Next</a>';
                    }

                    $field .= '</div>';
                }else{
                    $field .= esc_html__( 'No image uploaded', 'survform' );
                }
                break;
        }

        echo $field;
    }
}

/**
 * Output the login form
 * @param boolean, if set false, the form will be hidden by default
 * @return the login form output
 */
if( ! function_exists( 'surv_login_form' ) ) {
    function surv_login_form( $display = false ){
        $display_style = ! $display ? 'style="display:none;"' : '';
?>
    <div class="surv-login-form" <?php echo $display_style; ?>>
        <h4><?php echo esc_html( get_option( 'surv_text_login_form_title' ) ); ?></h4>
        <input type="text" name="surv_login_user" class="surv_form_text_field" placeholder="<?php echo esc_html( get_option( 'surv_text_login_username_placeholder' ) ); ?>" />
        <input type="password" name="surv_login_password" class="surv_form_text_field" placeholder="<?php echo esc_html( get_option( 'surv_text_login_password_placeholder' ) ); ?>" />
        <button type="button"><?php echo esc_html( get_option( 'surv_text_login_button_text' ) ); ?></button>
        <a href="javascript:void(0);" class="surv-switch-link"><?php echo esc_html( get_option( 'surv_text_register_link_text' ) ); ?></a>
    </div>
<?php
    }
}

/**
 * Output the register form
 * @param boolean, if set false, the form will be hidden by default
 * @return the register form output
 */
if( ! function_exists( 'surv_register_form' ) ) {
    function surv_register_form( $display = false ){
        $display_style = ! $display ? 'style="display:none;"' : '';
?>
    <div class="surv-register-form" <?php echo $display_style; ?>>
        <h4><?php echo esc_html( get_option( 'surv_text_register_form_title' ) ); ?></h4>
        <input type="text" name="surv_register_user" class="surv_form_text_field" placeholder="<?php echo esc_html( get_option( 'surv_text_register_email_placeholder' ) ); ?>" />
        <input type="password" name="surv_register_password" class="surv_form_text_field" placeholder="<?php echo esc_html( get_option( 'surv_text_login_password_placeholder' ) ); ?>" />
        <button type="button"><?php echo esc_html( get_option( 'surv_text_register_button_text' ) ); ?></button>
        <a href="javascript:void(0);" class="surv-switch-link"><?php echo esc_html( get_option( 'surv_text_login_link_text' ) ); ?></a>
    </div>
<?php
    }
}

/**
 * Output the surv form submit button and hidden data.
 * @return the submit button output
 */
if( ! function_exists( 'surv_submit_button' ) ) {
    function surv_submit_button(){
      $back_url = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : 'javascript:history.go(-1);';
?>
    <div class="surv-submit-screen">
        <h3><?php echo get_option( 'surv_text_submit_screen_title' ); ?></h3>
        <a href="<?php echo $back_url; ?>" class="surv-button surv-back-button">
          <?php esc_html_e( 'Back', 'survform' ); ?>
        </a>
        <?php if( get_option( 'surv_final_redirect_url' ) !== ''): ?>
        <a id="surv-final-back" href="<?php echo get_option( 'surv_final_redirect_url' );?>" class="surv-button surv-back-button" style="display: none;">
          <?php echo get_option( 'surv_final_back_text' ) !== '' ? get_option( 'surv_final_back_text' ) : esc_html__( 'Back', 'survform' ); ?>
        </a>
        <?php endif; ?>
        <button id="surv-form-submit" type="button"><?php echo esc_html( get_option( 'surv_text_submit_button_text' ) ); ?></button>
    </div>
<?php
    }
}

/**
 * Output the hidden field of form.
 */
if( ! function_exists( 'surv_submit_hidden_field' ) ) {
    function surv_submit_hidden_field(){
        $surv_name = get_post_meta( get_the_ID(), '_surv_campaign_name', true );
        echo '<input type="hidden" name="surv_form_page" value="'. esc_url( get_permalink() ) .'" />';
        echo '<input type="hidden" name="surv_form_name" value="'. esc_html( $surv_name ) .'" />';
        echo '<input type="hidden" name="surv_form_nonce" value="'. wp_create_nonce("surv_form_nonce") .'" />';
        echo '<input type="hidden" name="surv_form_post_id" value="" />';
        echo '<input type="hidden" name="surv_logged_user" value="' . get_current_user_id() . '" />';
    }
}

/**
 * Output the form class
 * @param class name
 */
if( ! function_exists( 'surv_form_class' ) ) {
    function surv_form_class( $class ){
        echo 'class="'. $class .' surv-form"';
    }
}

/**
 * Shortcode
 */
if( ! function_exists( 'survform_shortcode' ) ) {
    function survform_shortcode( $atts ){
        extract( shortcode_atts( array(
          'page_id' => 1,
          'width' => '100%',
          'height' => '500'
        ), $atts ) );

        $return = '<iframe class="surv-iframe" src="' . get_permalink( $page_id ) . '" width="'. $width .'" height="' . $height . '"></iframe>';
        return $return;
    }
}
add_shortcode( 'survform', 'survform_shortcode' );

/**
 * Site Header
 */
if( ! function_exists( 'surv_header' ) ) {
    function surv_header() {
        global $post;
        $surv_logo = get_post_meta( $post->ID, '_surv_logo', true );
    ?>
    <div id="surv-site-header">
        <h1 id="surv-site-logo">
            <a href="<?php echo home_url('/'); ?>" title="<?php bloginfo('name');?>">
                <?php if( $surv_logo !== '' ):?>
                         <img src="<?php echo $surv_logo; ?>" alt="<?php bloginfo( 'name' ); ?>" />
                <?php else:
                         bloginfo( 'name' );
                      endif;
                ?>
            </a>
        </h1>

        <a href="<?php echo home_url( '/' ); ?>" class="surv-back-site"><?php esc_html_e( 'Back To Home', 'survform' );?></a>
    </div>
    <?php
    }
}
add_action( 'survform_page_template_header', 'surv_header', 10 );
