<?php
/**
 * Form Metabox
 * @package SurvForm
 * @version 1.0.0
 */

function surv_form_metabox() {
    $prefix = '_surv_';

    $form = new_cmb2_box( array(
        'id'            => $prefix . 'metabox',
        'title'         => esc_html__( 'SurvForm Options', 'survform' ),
        'object_types'  => array( 'page' ), // Post type
        'context'       => 'normal',
        'priority'      => 'high',
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'campaign_name',
        'type'        => 'text',
        'name'       => esc_html__( 'Campaign Name', 'survform' ),
        'description' => esc_html__( 'Set the survey campaign name, it will be displayed on the backend.', 'survform' ),
        'default'     => 'New Survey'
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'required_sign_in_up',
        'type'        => 'switch',
        'name'       => esc_html__( 'Required Sign In or Sign Up?', 'survform' ),
        'description' => esc_html__( 'If yes, the signin and signup form will be appended as the last step of this survey form.', 'survform' ),
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'allow_skip',
        'type'        => 'switch',
        'name'       => esc_html__( 'Allow Skip The Question?', 'survform' ),
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'redirect_url',
        'type'        => 'text',
        'name'       => esc_html__( 'Redirect URL After Done', 'deco' ),
        'description' => esc_html__( 'Set a redirect URL after the user submit the form.', 'deco' ),
        'default'     => ''
    ) );

    $form->add_field( array(
        'id'          => $prefix . 'logo',
        'type'        => 'file',
        'name'       => esc_html__( 'LOGO', 'survform' ),
        'query_args' => array(
          'type' => array(
             'image/gif',
             'image/jpeg',
             'image/png'
          )
        ),
        'preview_size' => 'thumbnail',
    ) );

    // $group_field_id is the field id string, so in this case: $prefix . 'demo'
    $form_item = $form->add_field( array(
        'id'          => $prefix . 'items_group',
        'type'        => 'group',
        'description' => esc_html__( 'Create the surv form question below.', 'survform' ),
        'options'     => array(
            'group_title'   => esc_html__( 'Question {#}', 'survform' ), // {#} gets replaced by row number
            'add_button'    => esc_html__( 'Add Question', 'survform' ),
            'remove_button' => esc_html__( 'Remove Question', 'survform' ),
            'sortable'      => true,
            'remove_confirm' => esc_html__( 'Are you sure you want to delete this question?', 'survform' ),
            'closed'        => true
            // 'closed'     => true, // true to have the groups closed by default
        ),
    ) );
    /**
     * Group fields works the same, except ids only need
     * to be unique to the group. Prefix is not needed.
     *
     * The parent field's id needs to be passed as the first argument.
     */
    $form->add_group_field( $form_item, array(
        'name'       => esc_html__( 'Title', 'survform' ),
        'id'         => 'field_title',
        'type'       => 'text',
        // 'repeatable' => true, // Repeatable fields are supported w/in repeatable groups (for most types)
    ) );

    $form->add_group_field( $form_item, array(
        'name'        => esc_html__( 'Description', 'survform' ),
        'description' => esc_html__( 'Write a short description for this field item.', 'survform' ),
        'id'          => 'field_description',
        'type'        => 'textarea',
    ) );

    $form->add_group_field( $form_item, array(
        'name'        => esc_html__( 'Field Type', 'survform' ),
        'description' => esc_html__( 'Choose the field type for this form item.', 'survform' ),
        'id'          => 'field_type',
        'type'        => 'select',
        'default'     => 'checkbox',
        'options'     => array(
            'checkbox'  => esc_html__('Checkbox', 'survform'),
            'radio'  => esc_html__('Radio', 'survform'),
            'checkbox-image'  => esc_html__('Checkbox Images','survform'),
            'radio-image'  => esc_html__('Radio Images', 'survform'),
            'select'  => esc_html__('Select', 'survform'),
            'text' => esc_html__('Text Field', 'survform'),
            'email' => esc_html__('Email Field', 'survform'),
            'number' => esc_html__('Number Field', 'survform'),
            'url' => esc_html__('URL Field', 'survform'),
            'password' => esc_html__('Password Field', 'survform'),
            'textarea' => esc_html__('Textarea Field', 'survform'),
        )
    ) );


    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Field ID', 'survform' ),
        'description' => esc_html__( 'Please set an unique field ID, the ID should be the English characters.', 'survform' ),
        'id'   => 'field_id',
        'type' => 'text'
    ) );

    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Field Label', 'survform' ),
        'description' => esc_html__( 'Optional', 'survform' ),
        'id'   => 'field_label',
        'type' => 'text'
    ) );

    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Field Placeholder', 'survform' ),
        'description' => esc_html__( 'Optional', 'survform' ),
        'id'   => 'field_placeholder',
        'type' => 'text',
        'attributes' => array(
            'data-conditional-id' => wp_json_encode( array( $form_item, 'field_type' ) ),
            'data-conditional-value' => wp_json_encode( array( 'text', 'textarea', 'password', 'url', 'email', 'number' ) ),
        ),
    ) );

    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Field ID', 'survform' ),
        'description' => esc_html__( 'Please set an unique field ID, the ID should be the English characters.', 'survform' ),
        'id'   => 'field_id',
        'type' => 'text'
    ) );

    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Number of Choices Limited', 'survform' ),
        'description' => esc_html__( 'Maximum number of choices. Leave empty, there\'s no number limited.' , 'survform' ),
        'id'   => 'field_max_choices',
        'type' => 'text_small',
        'default' => '',
        'attributes' => array(
            'data-conditional-id' => wp_json_encode( array( $form_item, 'field_type' ) ),
            'data-conditional-value' => wp_json_encode( array( 'checkbox', 'checkbox-image' ) ),
        ),
    ) );

    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Upload Images', 'survform' ),
        'id'   => 'field_images',
        'type' => 'file_list',
        'attributes' => array(
            'data-conditional-id' => wp_json_encode( array( $form_item, 'field_type' ) ),
            'data-conditional-value' => wp_json_encode( array( 'checkbox-image', 'radio-image' ) ),
        ),
    ) );

    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Image Style', 'survform' ),
        'id'   => 'field_image_style',
        'type' => 'select',
        'options' => array(
            'normal' => esc_html__( 'Normal', 'survform' ),
            'icon' => esc_html__( 'Icon Style', 'survform' ),
        ),
        'attributes' => array(
            'data-conditional-id' => wp_json_encode( array( $form_item, 'field_type' ) ),
            'data-conditional-value' => wp_json_encode( array( 'checkbox-image', 'radio-image' ) ),
        ),
    ) );

    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Image Value Type', 'survform' ),
        'id'   => 'field_image_value_type',
        'type' => 'select',
        'options' => array(
            'url' => esc_html__( 'Image URL', 'survform' ),
            'title' => esc_html__( 'Image Title', 'survform' ),
            'id' => esc_html__( 'Image ID', 'survform' ),
        ),
        'attributes' => array(
            'data-conditional-id' => wp_json_encode( array( $form_item, 'field_type' ) ),
            'data-conditional-value' => wp_json_encode( array( 'checkbox-image', 'radio-image' ) ),
        ),
    ) );

    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Display Inline?', 'survform' ),
        'id'   => 'field_inline',
        'type' => 'switch',
        'attributes' => array(
            'data-conditional-id' => wp_json_encode( array( $form_item, 'field_type' ) ),
            'data-conditional-value' => wp_json_encode( array( 'checkbox', 'radio' ) ),
        ),
    ) );

    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Options', 'survform' ),
        'description' => esc_html__( 'Please enter the options line by line.', 'survform' ),
        'id'   => 'field_options',
        'type' => 'textarea',
        'attributes' => array(
            'data-conditional-id' => wp_json_encode( array( $form_item, 'field_type' ) ),
            'data-conditional-value' => wp_json_encode( array( 'checkbox', 'radio', 'select' ) ),
        ),
    ) );

     $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Condition Setting', 'survform' ),
        'description' => esc_html__( 'The conditions setting is only available to use for the radio and radio image field type.', 'survform' ),
        'id'   => 'condition_title',
        'type' => 'title',
    ) );


    $form->add_group_field( $form_item, array(
        'name' => esc_html__( 'Condition Value', 'survform' ),
        'description' => __( 'Please add the condition rules as the following format line by line. <p> Current Value 1: Question 3 <br/>...</p><p>The logic is when selecting value 1, directly go to question 3. Note, you only need to add the value and question number such like red: 3</p>', 'survform' ),
        'id'   => 'conditions',
        'type' => 'textarea',
        'attributes' => array(
            'data-conditional-id' => wp_json_encode( array( $form_item, 'field_type' ) ),
            'data-conditional-value' => wp_json_encode( array( 'radio', 'radio-image' ) ),
        ),
    ) );

    
}

add_action('cmb2_admin_init', 'surv_form_metabox' );
