<?php
/**
 * Page Template: SurvForm Template
 * @package SurvForm
 * @version 1.0.0
 */
?>
<!DOCTYPE html>
<html lang="en">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta name="viewport" content="width=device-width, minimum-scale=1.0, maximum-scale=1.0" />
    <?php wp_head(); ?>
</head>

<body <?php body_class();?>>

	<?php
	   /**
	    * @hook: 'survform_page_template_header'
	    * @useage: add_action( 'survform_page_template_header', 'HOOKED FUNCTION' );
	    */
	   do_action( 'survform_page_template_header' );
	?>

	<?php
		$id  = 'surv-form-' . get_the_ID();
		$form_items = get_post_meta( get_the_ID(), '_surv_items_group', true );
		$surv_name = get_post_meta( get_the_ID(), '_surv_form_name', true );
		$required_sign_in_up = get_post_meta( get_the_ID(), '_surv_required_sign_in_up', true );
		$allow_skip = get_post_meta( get_the_ID(), '_surv_allow_skip', true );
		$redirect_url = get_post_meta( get_the_ID(), '_surv_redirect_url', true );
		$current_step = isset( $_GET['step'] ) ? $_GET['step'] : 1;
	?>
	<div id="<?php echo $id; ?>" <?php surv_form_class( 'surv-default' ); ?> data-form-url="<?php echo get_permalink();?>" data-step="<?php echo $current_step;?>" data-redirect="<?php echo esc_url($redirect_url);?>">
		  	<?php
			$step = 1;
		  	foreach ( (array) $form_items as $key => $field ):
				$field_prefix = '_surv_';
				$field_type = isset( $field['field_type'] ) ? esc_html( $field['field_type'] ) : 'checkbox';
				$field_title = isset( $field['field_title'] ) ? esc_html( $field['field_title'] ) : '';
				$field_desc = isset( $field['field_description'] ) ? wpautop( $field['field_description'] ) : '';
				$field_id = isset( $field['field_id'] ) && $field['field_id'] !== '' ? $field_prefix . esc_html( $field['field_id'] ) : $field_prefix . esc_html( surv_random( 8 ) );
				$field_label = isset( $field['field_label'] ) ? esc_html( $field['field_label'] ) : '';
				$field_placeholder = isset( $field['field_placeholder'] ) ? esc_html( $field['field_placeholder'] ) : '';
				$field_images = isset( $field['field_images'] ) ? $field['field_images'] : array();
				$field_options = isset( $field['field_options'] ) ? $field['field_options'] : '';
				$field_inline = isset( $field['field_inline'] ) ? $field['field_inline'] : '';
				$field_max_choices = isset( $field['field_max_choices'] ) && $field['field_max_choices'] !== '' ? $field['field_max_choices'] : -1;
				$field_image_style = isset( $field['field_image_style'] ) ? $field['field_image_style'] : 'normal';
				$field_image_value_type = isset( $field['field_image_value_type'] ) ? $field['field_image_value_type'] : 'url';

				$conditions = isset( $field['conditions'] ) ? $field['conditions'] : '';
				$conditions_data = [];

				if( $conditions !== '' ) {
					$conditions = preg_split("/\r\n|\n|\r/", $conditions);
					foreach( $conditions as $condition ) {
						$condition = explode( ':', $condition );
						$conditions_data[] = array(
							'spec_value' => $condition[0],
							'spec_step' => $condition[1]
						);
					}
				}
		  	?>

		  	<?php if( $step == 1 && ! isset( $_GET['step'] ) || isset( $_GET['step'] ) && $_GET['step'] == $step ): ?>
		  	<!--form item-->
		  	<div class="surv-form-item" data-field-type="<?php echo $field_type;?>" data-image-style="<?php echo isset($field['field_image_style']) ? $field['field_image_style'] : '';?>" data-conditions='<?php echo count( $conditions_data ) > 0 ? json_encode( $conditions_data ) : '';?>' data-max-choices="<?php echo esc_attr( $field_max_choices ); ?>">
				<div class="surv-content">
					<h3 class="surv-form-question"><?php echo $field_title; ?></h3>
					<div class="surv-form-desc"><?php echo $field_desc; ?></div>
					<?php if( $field_type == 'checkbox-image' || $field_type == 'radio-image' ): ?>
						<div class="surv-selected-images"></div>
					<?php endif;?>
				</div>

				<div class="surv-options">
					<?php
					   surv_fields( $args = array(
					   	   'field_type' => $field_type,
					   	   'id' => $field_id,
					   	   'label' => $field_label,
					   	   'placeholder' => $field_placeholder,
					   	   'images' => $field_images,
					   	   'image_value_type' => $field_image_value_type,
					   	   'image_style' => $field_image_style,
					   	   'options' => $field_options,
					   	   'inline'  => $field_inline
					   ) );
					?>
				</div>
			</div>
			<!--//form item-->

			<!--Next Bottom Bar-->
			<div class="surv-bottom-bar" data-field-type="<?php echo $field_type;?>">
				<?php
				$backlink = get_permalink();

				if( isset( $_GET['step'] ) && $_GET['step'] > 1 ):
					if( $current_step > 1 ) {
						$previous_step = isset($_GET['ref']) && $_GET['ref'] !== '' ? $_GET['ref'] : $current_step - 1;
						$backlink = get_permalink() . '?step=' . $previous_step;
					}
				?>
				<a class="surv-button surv-back-button" href="<?php echo $backlink; ?>"><?php esc_html_e( 'Back', 'survform' ); ?></a>
			    <?php endif; ?>

				<?php if( $step < count( $form_items ) + 1 ): ?>
					<?php if( $allow_skip ) : ?>
						<a href="?step=<?php echo $step + 1; ?>" class="surv-skip-link"><?php esc_html_e( 'Skip', 'survform' ); ?></a>
					<?php endif; ?>
					<a href="javascript:void(0);" data-next="<?php echo $step + 1; ?>" class="surv-button surv-next-button disabled"><?php esc_html_e( 'Next', 'survform' ); ?></a>
				<?php endif;?>
			</div>
			<?php endif; ?>

			<?php $step++; endforeach; ?>

			<!--Submit Screen-->
			<?php if( isset( $_GET['step'] ) && $_GET['step'] > count( $form_items ) ) : ?>
				<div class="surv-form-submit">

					<?php if( ! is_user_logged_in() && $required_sign_in_up == 'on'): ?>
					<div class="surv-sign-in-up">
						<h3><?php echo esc_html( get_option( 'surv_text_almost_have_done_title' ) ); ?></h3>
						<?php surv_login_form( $display = false );?>
						<?php surv_register_form( $display = true );?>
					</div>
					<?php else: ?>
						<?php surv_submit_button(); ?>
				    <?php endif; ?>
				</div>
			<?php endif; ?>

			<!--Don't delete the following user id hidden field.-->
			<?php surv_submit_hidden_field();?>
	</div>

	<?php
	   /**
	    * @hook: 'survform_page_template_footer'
	    * @useage: add_action( 'survform_page_template_footer', 'HOOKED FUNCTION' );
	    */
	   do_action( 'survform_page_template_footer' );
	?>

	<?php wp_footer(); ?>
</body>
</html>
